summaryrefslogtreecommitdiff
path: root/indra/newview/llcommandhandler.h
diff options
context:
space:
mode:
authorMonroe Williams <monroe@lindenlab.com>2009-08-27 19:00:18 +0000
committerMonroe Williams <monroe@lindenlab.com>2009-08-27 19:00:18 +0000
commit745845f79987e4b4ab7f5728746a0eda8898930f (patch)
treef10efd4a638a6a7eda92a960cdb97e5256ff736a /indra/newview/llcommandhandler.h
parent71344b233d5ae3d5262a492b636af04544952611 (diff)
svn merge -r 129841:129910 svn+ssh://svn.lindenlab.com/svn/linden/branches/moss/pluginapi_05-merge@129910
svn merge -r 129913:131718 svn+ssh://svn.lindenlab.com/svn/linden/branches/pluginapi/pluginapi_05 Some branch shenannigans in the pluginapi_05 branch caused this to become a two-part merge.
Diffstat (limited to 'indra/newview/llcommandhandler.h')
-rw-r--r--indra/newview/llcommandhandler.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/indra/newview/llcommandhandler.h b/indra/newview/llcommandhandler.h
index ab4c2cc488..5cb3ee73d4 100644
--- a/indra/newview/llcommandhandler.h
+++ b/indra/newview/llcommandhandler.h
@@ -47,7 +47,7 @@ public:
// Your code here
bool handle(const LLSD& tokens, const LLSD& query_map,
- LLWebBrowserCtrl* web)
+ LLMediaCtrl* web)
{
if (tokens.size() < 1) return false;
LLUUID id( tokens[0] );
@@ -60,7 +60,7 @@ LLFooHandler gFooHandler;
*/
-class LLWebBrowserCtrl;
+class LLMediaCtrl;
class LLCommandHandler
{
@@ -68,14 +68,14 @@ public:
LLCommandHandler(const char* command, bool allow_from_untrusted_browser);
// Automatically registers object to get called when
// command is executed. All commands can be processed
// in links from LLWebBrowserCtrl, but some (like teleport)
// should not be allowed from outside the app.
virtual ~LLCommandHandler();
virtual bool handle(const LLSD& params,
const LLSD& query_map,
- LLWebBrowserCtrl* web) = 0;
+ LLMediaCtrl* web) = 0;
// For URL secondlife:///app/foo/bar/baz?cat=1&dog=2
// @params - array of "bar", "baz", possibly empty
// @query_map - map of "cat" -> 1, "dog" -> 2, possibly empty
@@ -91,7 +91,7 @@ public:
static bool dispatch(const std::string& cmd,
const LLSD& params,
const LLSD& query_map,
- LLWebBrowserCtrl* web,
+ LLMediaCtrl* web,
bool trusted_browser);
// Execute a command registered via the above mechanism,
// passing string parameters.
@@ -68,14 +68,14 @@ public:
// Automatically registers object to get called when
// command is executed. All commands can be processed
- // in links from LLWebBrowserCtrl, but some (like teleport)
+ // in links from LLMediaCtrl, but some (like teleport)
// should not be allowed from outside the app.
virtual ~LLCommandHandler();